==> ejc-sddjsorg-api-3.0.0-20211018.072306-27-sources.jar: com/ejianc/business/production/vo/CurrencyVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-货币出资情况
 * 
 * @author generator
 * 
 */
public class CurrencyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id(申请单id)
    private java.lang.String inOutCaptail; // 内/外部出资方
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    private java.lang.String captailType; // 出资人类别
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    private java.math.BigDecimal paidCapital; // 实缴资本
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    private java.math.BigDecimal equityRatio; // 股权比例
    

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211026.022736-78-sources.jar: com/ejianc/business/production/vo/CurrencyVO.java <==
package com.ejianc.business.production.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-货币出资情况
 * 
 * @author generator
 * 
 */
public class CurrencyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id(申请单id)
    private java.lang.String inOutCaptail; // 内/外部出资方
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    private java.lang.String captailType; // 出资人类别
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    private java.math.BigDecimal paidCapital; // 实缴资本
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    private java.math.BigDecimal equityRatio; // 股权比例
    private Boolean whetherShareholder;//是否新股东
    private BigDecimal capitalIncreaseFrontRatio;


    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }

    public Boolean getWhetherShareholder() {
        return whetherShareholder;
    }

    public void setWhetherShareholder(Boolean whetherShareholder) {
        this.whetherShareholder = whetherShareholder;
    }

    public BigDecimal getCapitalIncreaseFrontRatio() {
        return capitalIncreaseFrontRatio;
    }

    public void setCapitalIncreaseFrontRatio(BigDecimal capitalIncreaseFrontRatio) {
        this.capitalIncreaseFrontRatio = capitalIncreaseFrontRatio;
    }
}
